@@ -39,6 +39,9 @@ class CBOMAdmin(admin.ModelAdmin):
     search_fields = ['customer__description', 'description', 'product']
     inlines = [CBOMItemInline, ]
 
+    class Media:
+        js = ('aps_bom/cbom_admin.js', )
+
 
 class CBOMItemAdmin(admin.ModelAdmin):
     list_display = ['bom', 'epn', 'qty', 'unit', 'position']
